@@ -1,8 +1,3 @@
-# $Id: /mirror/coderepos/lang/perl/Text-MeCab/trunk/lib/Text/MeCab.pm 43505 2008-03-09T11:09:55.267941Z daisuke  $
-#
-# Copyright (c) 2006-2008 Daisuke Maki <daisuke@endeworks.jp>
-# All rights reserved.
-
 package Text::MeCab;
 use strict;
 use warnings;
@@ -11,7 +6,7 @@ use Exporter 'import';
 our ($VERSION, @ISA, %EXPORT_TAGS, @EXPORT_OK);
 BEGIN
 {
-    $VERSION = '0.20007';
+    $VERSION = '0.20008';
     if ($] > 5.006) {
         require XSLoader;
         XSLoader::load(__PACKAGE__, $VERSION);
@@ -50,7 +45,7 @@ sub new
         }
     }
 
-    $class->_XS_new(\@args);
+    $class->_xs_create(\@args);
 }
 
 1;
